@@ -168,10 +168,8 @@ OC.L10N.register(
     "Can edit" : "يمكن تعديله",
     "Can share" : "يمكن مشاركته",
     "Can manage" : "يمكن إدارته",
-    "Owner" : "المالك",
     "Delete" : "حذف ",
     "Failed to create share with {displayName}" : "فشل في إنشاء المشاركة مع {displayName}",
-    "Transfer" : "نقل",
     "Add a new list" : "اضف قائمة جديدة",
     "Archive all cards" : "أرشفة جميع البطاقات ",
     "Delete list" : "حذف القائمة",
@@ -188,7 +186,6 @@ OC.L10N.register(
     "Share from Files" : "مشاركة من الملفات",
     "Add this attachment" : "إضافة هذا المرفق",
     "Show in Files" : "عرض في الملفات ",
-    "Download" : "تنزيل",
     "Delete Attachment" : "مسح المرفق",
     "Restore Attachment" : "إستعادة المرفق",
     "File to share" : "ملف للمشاركة",
@@ -212,8 +209,6 @@ OC.L10N.register(
     "Select Date" : "اختر التاريخ ",
     "Today" : "اليوم",
     "Tomorrow" : "غدا",
-    "Next week" : "الاسبوع القادم",
-    "Next month" : "الشهر القادم",
     "Save" : "حفظ",
     "The comment cannot be empty." : "التعليق لايمكن ان يكون فارغا.",
     "The comment cannot be longer than 1000 characters." : "التعليق لا يمكن ان يكون اطول من 1000 حرف.",
@@ -284,9 +279,6 @@ OC.L10N.register(
     "Share {file} with a Deck card" : "مشاركة الملف {file} مع بطاقة Deck",
     "Share" : "مشاركة ",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "دك (Deck) هو أداة تنظيم باسلوب كانبان (kanban) تهدف إلى التخطيط الشخصي وتنظيم المشروع للفرق مع نيكست كلاود (Nextcloud).\n- 📥 إضافة مهامك إلى البطاقات وترتيبها\n- 📄 كتابة ملاحظات إضافية  باستخدام مارك داون (markdown)\n- 🔖 تعيين تسميات لتنظيم أفضل\n- 👥 شارك مع فريقك أو أصدقائك أو عائلتك\n- 📎 إرفاق الملفات وتضمينها بالوصف المستخدم فيه مارك داون (markdown)\n- 💬 ناقش مع فريقك باستخدام التعليقات\n- ⚡ تتبع التغييرات في تيار النشاط\n- 🚀 اجعل مشروعك منظماً",
-    "Creating the new card…" : "أنشى البطاقة الجديدة ",
-    "\"{card}\" was added to \"{board}\"" : "\"{بطاقة}\" تمت إضافتها في \"{اللوح}\"",
-    "(circle)" : "(دائرة)",
     "This week" : "هذا الأسبوع"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
