@@ -106,8 +106,6 @@ OC.L10N.register(
     "Select a board" : "נא לבחור לוח",
     "Select a list" : "בחר רשימה",
     "Cancel" : "ביטול",
-    "Close" : "סגירה",
-    "Create card" : "יצירת כרטיס",
     "Select a card" : "נא לבחור כרטיס",
     "Select the card to link to a project" : "נא לבחור את הכרטיס לקישור למיזם",
     "Link to card" : "קישור לכרטיס",
@@ -157,10 +155,8 @@ OC.L10N.register(
     "Can edit" : "ניתן לערוך",
     "Can share" : "Can share",
     "Can manage" : "הרשאת ניהול",
-    "Owner" : "בעלות",
     "Delete" : "מחיקה",
     "Failed to create share with {displayName}" : "יצירת השיתוף עם {displayName} נכשלה",
-    "Transfer" : "העברה",
     "Add a new list" : "הוסף רשימה חדשה",
     "Archive all cards" : "ארכיב את כל הכרטיסים",
     "Delete list" : "מחיקת רשימה",
@@ -177,7 +173,6 @@ OC.L10N.register(
     "Share from Files" : "שיתוף מקבצים",
     "Add this attachment" : "הוספת קובץ מצורף זה",
     "Show in Files" : "הצגה בקבצים",
-    "Download" : "הורדה",
     "Delete Attachment" : "מחיקת קובץ מצורף",
     "Restore Attachment" : "שחזור קובץ מצורף",
     "File to share" : "קובץ לשיתוף",
@@ -200,8 +195,6 @@ OC.L10N.register(
     "Select Date" : "בחירת תאריך",
     "Today" : "היום",
     "Tomorrow" : "מחר",
-    "Next week" : "השבוע הבא",
-    "Next month" : "החודש הבא",
     "Save" : "שמור",
     "The comment cannot be empty." : "ההערה לא יכולה להיות ריקה.",
     "The comment cannot be longer than 1000 characters." : "אורך ההערה לא יכול לחצות את רף 1000 התווים.",
@@ -225,7 +218,6 @@ OC.L10N.register(
     "Archive card" : "העברת כרטיס לארכיון",
     "Delete card" : "מחיקת כרטיס לארכיון",
     "Move card to another board" : "העברת כרטיס ללוח אחר",
-    "List is empty" : "הרשימה ריקה",
     "Card deleted" : "הכרטיס נמחק",
     "seconds ago" : "לפני מספר שניות",
     "All boards" : "כל הלוחות",
@@ -255,7 +247,6 @@ OC.L10N.register(
     "Delete the board?" : "למחוק את הלוח הזה?",
     "Loading filtered view" : "טוען תצוגה מסוננת",
     "No due" : "אין תאריך יעד",
-    "No results found" : "לא נמצאו תוצאות",
     "No upcoming cards" : "אין כרטיסים עתידיים",
     "upcoming cards" : "כרטיסים עתידיים",
     "Link to a board" : "קישור ללוח",
@@ -268,7 +259,6 @@ OC.L10N.register(
     "Share {file} with a Deck card" : "שיתוף {file} עם כרטיס חפיסה",
     "Share" : "שיתוף",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck הוא כלי ארגון בסגנון kanban המכוון לתכנון אישי ולארגון פרויקטים עבור צוותים המשולבים ב- Nextcloud.\n\n\n- 📥 הוסף את המשימות שלך לכרטיסים וסדר אותן\n- 📄 רשמו הערות נוספות ב-markdown\n- 🔖הקצה תוויות לארגון טוב עוד יותר\n- 👥 שתף עם הצוות שלך, חברים, או משפחה\n- 📎 צרף קבצים והטמע אותם בתיאור ה-markdown שלך\n- 💬 שוחח עם הצוות שלך באמצעות הערות\n- ⚡ עקוב אחר שינויים בזרם הפעילות\n- 🚀 ארגנו את הפרויקט שלכם",
-    "(circle)" : "(מעגל)",
     "This week" : "השבוע"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
