@@ -34,7 +34,6 @@ OC.L10N.register(
     "Missing a temporary folder" : "Відсутня тека для тимчасових файлів",
     "Could not write file to disk" : "Неможливо записати файл на диск",
     "A PHP extension stopped the file upload" : "Розширення PHP призупинило завантаження файлу",
-    "Card not found" : "Картку не знайдено",
     "Card details" : "Деталі картки",
     "Add board" : "Додати дошку",
     "Select the board to link to a project" : "Виберіть дошку для прив'зки до проєкту",
@@ -43,7 +42,6 @@ OC.L10N.register(
     "Select a board" : "Вибрати дошку",
     "Select a list" : "Виберіть список",
     "Cancel" : "Скасувати",
-    "Close" : "закрити",
     "Select a card" : "Вибрати картку",
     "Select the card to link to a project" : "Виберіть картку для прив'язки до проєкту",
     "Link to card" : "Прив'язати до картки",
@@ -88,9 +86,7 @@ OC.L10N.register(
     "Can edit" : "Можна редагувати",
     "Can share" : "Can share",
     "Can manage" : "Може керувати",
-    "Owner" : "Власник",
     "Delete" : "Вилучити",
-    "Transfer" : "Передати",
     "Add a new list" : "Додати новий список",
     "Delete list" : "Вилучити список",
     "Add a new card" : "Додати нову картку",
@@ -98,14 +94,9 @@ OC.L10N.register(
     "Add a new tag" : "Додати нову позначку",
     "title and color value must be provided" : "потрібно зазначити назву та колір",
     "Members" : "Учасники",
-    "Upload new files" : "Додати файл",
-    "Share from Files" : "Відкрити Файли",
     "Add this attachment" : "Долучити вкладення",
-    "Download" : "Завантажити",
     "Delete Attachment" : "Забрати вкладення",
     "Restore Attachment" : "Відновити вкладення",
-    "File to share" : "Виберіть файл для надання доступу",
-    "Invalid path selected" : "Вибрано неправильний шлях",
     "Attachments" : "Вкладення",
     "Comments" : "Коментарі",
     "Modified" : "Змінено",
@@ -120,8 +111,6 @@ OC.L10N.register(
     "Select Date" : "Вкажіть дату",
     "Today" : "Сьогодні",
     "Tomorrow" : "Завтра",
-    "Next week" : "Наступний тиждень",
-    "Next month" : "Наступний місяць",
     "Save" : "Зберегти",
     "In reply to" : "У відповідь",
     "Reply" : "Відповісти",
@@ -148,11 +137,6 @@ OC.L10N.register(
     "Limit deck usage of groups" : "Обмежити доступ до колоди для груп",
     "Board details" : "Деталі дошки",
     "Edit board" : "Редагувати дошку",
-    "Clone board" : "Копіювати дошку",
-    "Unarchive board" : "Розархівувати дошку",
-    "Archive board" : "Архівувати дошку",
-    "No notifications" : "Немає сповіщень",
-    "Delete board" : "Вилучити дошку",
     "Board {0} deleted" : "Дошку {0} вилучено",
     "An error occurred" : "Виникла помилка",
     "Delete the board?" : "Вилучити дошку?",
@@ -160,8 +144,6 @@ OC.L10N.register(
     "Link to a card" : "Прив'язати до картки",
     "Something went wrong" : "От халепа!",
     "Maximum file size of {size} exceeded" : "Досягнуто максимальний розмір файлу {size}",
-    "Share" : "Поділитися",
-    "(circle)" : "(коло)",
     "This week" : "Цього тижня"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
