@@ -168,10 +168,8 @@ OC.L10N.register(
     "Can edit" : "可以编辑",
     "Can share" : "可以共享",
     "Can manage" : "可以管理",
-    "Owner" : "所有者",
     "Delete" : "删除",
     "Failed to create share with {displayName}" : "用 {displayName} 创建分享失败",
-    "Transfer" : "传输",
     "Add a new list" : "添加新列表",
     "Archive all cards" : "归档所有卡片",
     "Delete list" : "删除列表",
