@@ -173,8 +173,11 @@ OC.L10N.register(
     "Owner" : "所有者",
     "Delete" : "刪除",
     "Failed to create share with {displayName}" : "無法為 {displayName} 創建分享",
+    "Are you sure you want to transfer the board {title} for {user}?" : "您想要轉移 {user} 的面板 {title} 嗎？",
     "Transfer the board." : "轉移面板。",
     "Transfer" : "轉移",
+    "Transfer the board for {user} successfully" : "轉移 {user} 的面板成功",
+    "Failed to transfer the board for {user}" : "轉移 {user} 的面板失敗",
     "Add a new list" : "添加一張新清單",
     "Archive all cards" : "封存所有卡片",
     "Delete list" : "刪除清單",
@@ -294,8 +297,6 @@ OC.L10N.register(
     "\"{card}\" was added to \"{board}\"" : "\"{card}\" 已添加到 \"{board}\"",
     "(circle)" : "（社交圈子）",
     "This week" : "本星期",
-    "Are you sure you want to transfer the board {title} for {user} ?" : "您想要轉移 {user} 的面板 {title} 嗎？",
-    "Transfer the board for {user} successfully" : "轉移 {user} 的面板成功",
-    "Failed to transfer the board for {user}" : "轉移 {user} 的面板失敗"
+    "Are you sure you want to transfer the board {title} for {user} ?" : "您想要轉移 {user} 的面板 {title} 嗎？"
 },
 "nplurals=1; plural=0;");
