@@ -94,7 +94,7 @@ class CardApiController extends ApiController {
 	 *
 	 * Update a card
 	 */
-	public function update($title, $type, $order = 0, $description = '', $owner, $duedate = null, $archived = null) {
+	public function update($title, $type, $owner, $description = '', $order = 0, $duedate = null, $archived = null) {
 		$card = $this->cardService->update($this->request->getParam('cardId'), $title, $this->request->getParam('stackId'), $type, $owner, $description, $order, $duedate, 0, $archived);
 		return new DataResponse($card, HTTP::STATUS_OK);
 	}
